Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(159)

Unified Diff: ppapi/cpp/dev/file_chooser_dev.h

Issue 10414085: Modified the pepper file chooser API to support filtering files by extensions. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ppapi/c/dev/ppb_file_chooser_dev.h ('k') | ppapi/cpp/dev/file_chooser_dev.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ppapi/cpp/dev/file_chooser_dev.h
diff --git a/ppapi/cpp/dev/file_chooser_dev.h b/ppapi/cpp/dev/file_chooser_dev.h
index b588ac85a379ebff01d2109f764b50c6c3e64a5f..ed60f60b3c4d562361df4e4f57cd9ac8ddb13d2b 100644
--- a/ppapi/cpp/dev/file_chooser_dev.h
+++ b/ppapi/cpp/dev/file_chooser_dev.h
@@ -36,19 +36,18 @@ class FileChooser_Dev : public Resource {
/// In order to get the list of files in a directory, the
/// PPB_DirectoryReader_Dev interface must be used.
///
/// @param accept_mime_types A comma-separated list of MIME types such as
/// "audio/ *,text/plain" (note there should be no space between the '/' and
/// the '*', but one is added to avoid confusing C++ comments). The dialog
/// may restrict selectable files to the specified MIME types. An empty string
/// or an undefined var may be given to indicate that all types should be
/// accepted.
- ///
- /// TODO(darin): What if the mime type is unknown to the system? The plugin
- /// may wish to describe the mime type and provide a matching file extension.
- /// It is more webby to use mime types here instead of file extensions.
FileChooser_Dev(const InstanceHandle& instance,
PP_FileChooserMode_Dev mode,
- const Var& accept_mime_types);
+ const Var& accept_types);
FileChooser_Dev(const FileChooser_Dev& other);
« no previous file with comments | « ppapi/c/dev/ppb_file_chooser_dev.h ('k') | ppapi/cpp/dev/file_chooser_dev.cc » ('j') | no next file with comments »
@@ -36,19 +36,18 @@ class FileChooser_Dev : public Resource {
/// PPB_DirectoryReader_Dev interface must be used.
///
- /// @param accept_mime_types A comma-separated list of MIME types such as
- /// "audio/ *,text/plain" (note there should be no space between the '/' and
- /// the '*', but one is added to avoid confusing C++ comments). The dialog
- /// may restrict selectable files to the specified MIME types. An empty string
- /// or an undefined var may be given to indicate that all types should be
+ /// @param accept_types A comma-separated list of MIME types and file
+ /// extensions such as "audio/ *,text/plain,.html" (note there should be
+ /// no space between the '/' and the '*', but one is added to avoid confusing
+ /// C++ comments). The dialog may restrict selectable files to the specified
+ /// MIME types and file extensions. If a string in the comma-separated list
+ /// begins with a period (.) then the string is interpreted as a file
+ /// extension, otherwise it is interpreted as a MIME-type. An empty string or
+ /// an undefined var may be given to indicate that all types should be
/// accepted.

Powered by Google App Engine
This is Rietveld 408576698